==> upload-api-client-internal-2.55.0.tgz: package/src/models/UploadManagerParams.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */

import type { AccountId } from "./AccountId";
import type { CancellationToken } from "./CancellationToken";
import type { FileMetadata } from "./FileMetadata";
import type { FilePathDefinition } from "./FilePathDefinition";
import type { FileTagName } from "./FileTagName";
import type { MimeType } from "./MimeType";
import type { OriginalFileName } from "./OriginalFileName";
import type { SizeInBytes } from "./SizeInBytes";

/**
 * Parameter object passed to the ```UploadManager.upload(params)``` method in the Upload SDKs.
 */
export type UploadManagerParams = {
  /**
   * An arbitrary JSON object to store against the file as metadata.
   *
   * You can retrieve this later via a GetFileDetails request.
   */
  metadata?: FileMetadata;
  /**
   * The file's MIME type.
   */
  mime?: MimeType;
  /**
   * The file's original name on the user's device.
   */
  originalFileName?: OriginalFileName;
  /**
   * The path to upload the file to.
   */
  path?: FilePathDefinition;
  /**
   * The file tags to store against the file.
   *
   * When you associate file tags with a file, Upload checks which rules match the tags (if any) and applies those rules to the upload request:
   *
   * Rules can include max file size checks, traffic limit checks, rate limit checks, and so forth. These are configured in the Upload Dashboard.
   */
  tags?: Array<FileTagName>;
  accountId: AccountId;
  /**
   * Cancellation token to allow the upload to be cancelled after it has started.
   */
  cancellationToken?: CancellationToken;
  /**
   * The data to upload.
   *
   * The supported types for this parameter vary between the different Upload SDKs.
   *
   * Please refer to each SDK's documentation for this field's type.
   */
  data: any;
  maxConcurrentUploadParts?: number;
  /**
   * Size of the file `data` being uploaded, in bytes.
   *
   * Conditional: only include if both `data` is a stream.
   */
  size?: SizeInBytes;
};

==> upload-api-client-internal-2.64.0.tgz: package/src/models/UploadManagerParams.ts <==
/* istanbul ignore file */
/* tslint:disable */
/* eslint-disable */

import type { AccountId } from "./AccountId";
import type { CancellationToken } from "./CancellationToken";
import type { FileMetadata } from "./FileMetadata";
import type { FilePathDefinition } from "./FilePathDefinition";
import type { FileTagName } from "./FileTagName";
import type { MimeType } from "./MimeType";
import type { OriginalFileName } from "./OriginalFileName";
import type { SizeInBytes } from "./SizeInBytes";

/**
 * Parameter object passed to the ```UploadManager.upload(params)``` method in the Upload SDKs.
 */
export type UploadManagerParams = {
  /**
   * Arbitrary JSON to store against the file as metadata.
   *
   * You can retrieve this later via a GetFileDetails request.
   */
  metadata?: FileMetadata;
  /**
   * The file's MIME type.
   */
  mime?: MimeType;
  /**
   * The file's original name on the user's device.
   */
  originalFileName?: OriginalFileName;
  /**
   * The path to upload the file to.
   */
  path?: FilePathDefinition;
  /**
   * The file tags to store against the file.
   *
   * When you associate file tags with a file, Upload checks which rules match the tags (if any) and applies those rules to the upload request:
   *
   * Rules can include max file size checks, traffic limit checks, rate limit checks, and so forth. These are configured in the Upload Dashboard.
   */
  tags?: Array<FileTagName>;
  accountId: AccountId;
  /**
   * Cancellation token to allow the upload to be cancelled after it has started.
   */
  cancellationToken?: CancellationToken;
  /**
   * The data to upload.
   *
   * The supported types for this parameter vary between the different Upload SDKs.
   *
   * Please refer to each SDK's documentation for this field's type.
   */
  data: any;
  maxConcurrentUploadParts?: number;
  /**
   * Size of the file `data` being uploaded, in bytes.
   *
   * Conditional: only include if both `data` is a stream.
   */
  size?: SizeInBytes;
};
